@@ -28,19 +28,8 @@ namespace Breeze
 
     //_______________________________________________
     BusyIndicatorEngine::BusyIndicatorEngine( QObject* object ):
-        BaseEngine( object ),
-        _animation( new Animation( duration(), this ) ),
-        _value( 0 )
-    {
-
-        // setup animation
-        _animation.data()->setStartValue( 0 );
-        _animation.data()->setEndValue( 2*Metrics::ProgressBar_BusyIndicatorSize );
-        _animation.data()->setTargetObject( this );
-        _animation.data()->setPropertyName( "value" );
-        _animation.data()->setLoopCount( -1 );
-
-    }
+        BaseEngine( object )
+    {}
 
     //_______________________________________________
     bool BusyIndicatorEngine::registerWidget( QObject* object )
@@ -79,7 +68,8 @@ namespace Breeze
         BaseEngine::setDuration( value );
 
         // restart timer with specified time
-        _animation.data()->setDuration( value );
+        if( _animation )
+        { _animation.data()->setDuration( value ); }
 
     }
 
@@ -94,13 +84,33 @@ namespace Breeze
             data.data()->setAnimated( value );
 
             // start timer if needed
-            if( value && !_animation.data()->isRunning() )
-            { _animation.data()->start(); }
+            if( value )
+            {
+                if( !_animation )
+                {
+
+                    // create animation if not already there
+                    _animation = new Animation( duration(), this );
+
+                    // setup
+                    _animation.data()->setStartValue( 0 );
+                    _animation.data()->setEndValue( 2*Metrics::ProgressBar_BusyIndicatorSize );
+                    _animation.data()->setTargetObject( this );
+                    _animation.data()->setPropertyName( "value" );
+                    _animation.data()->setLoopCount( -1 );
+                    _animation.data()->setDuration( duration() );
+
+                }
+
+                // start if  not already running
+                if( !_animation.data()->isRunning() )
+                { _animation.data()->start(); }
+
+            }
 
         }
 
-        return;
-
+        
     }
 
 
@@ -144,8 +154,27 @@ namespace Breeze
 
         }
 
-        if( !animated ) _animation.data()->stop();
+        if( _animation && !animated )
+        {
+            _animation.data()->stop();
+            _animation.data()->deleteLater();
+            _animation.clear();
+        }
 
     }
 
+    //__________________________________________________________
+    bool BusyIndicatorEngine::unregisterWidget( QObject* object )
+    {
+        const bool removed( _data.unregisterWidget( object ) );
+        if( _animation && _data.isEmpty() )
+        {
+            _animation.data()->stop();
+            _animation.data()->deleteLater();
+            _animation.clear();
+        }
+
+        return removed;
+    }
+
 }
